# Changelog

<!-- <START NEW CHANGELOG ENTRY> -->
## 0.2.0 (July 9, 2024)
* Initial release with the menu items: "Hide before print", "Undo hide before 
  print", "Insert 
  Algebra with Sympy initialization code", "Algebra with Sympy Docs", "Insert 
  JupyterPiDAQ initialization code", "JupyterPiDAQ Docs", "Insert PandasGUI 
  initialization code", "Insert load data from CSV code", "Insert New 
  Calculated 
  Column GUI", 
  "Insert New Plot 
  GUI", "Insert New Fit GUI", "PandasGUI Docs".
<!-- <END NEW CHANGELOG ENTRY> -->
